Skip to contents

A simulated dataset including individual information such as unique ID, ICD-10 and diagnosis date (year).

Usage

diag_df

Format

diag_df A data frame with 30,024 rows and 3 columns:

id

Unique personal identifier

code

ICD-10 codes

diag_year

Year of diagnosis

Code used to simulate this dataset can be found in /data-raw directory