Data frame including Norwegian municipality codes valid in 2016.
kommuner_2016
A data frame with 429 rows and 2 columns:
- code
Code of municipality (2016)
- name
Name of municipality
Code used to simulate this dataset can be found in /data-raw directory