A simulated dataset including time-variant individual information such as year of residence and place of residence (codes)
var_df
A data frame with 270,216 rows and 3 columns:
- id
Unique personal identifier
- code
Code place of residence (time varying)
- year
Year of residence
Code used to simulate this dataset can be found in /data-raw directory